@@ -25,9 +25,11 @@ class LARDA :
     """init a new larda instance
 
     Args:
-        data_source (str, optional): either ``'local'`` or ``'remote'``
+        data_source (str, optional): either ``'local'``, ``'remote'`` or ``'filepath'``
         uri: link to backend
 
+    Returns:
+        larda object
     """
     def __init__(self, data_source='local', uri=None):
         if data_source == 'local':
@@ -39,6 +41,11 @@ class LARDA :
             self.uri = uri
             resp = requests.get(self.uri + '/api/')
             self.campaign_list = resp.json()['campaign_list']
+        elif data_source == 'filepath':
+            self.data_source = 'filepath'
+            self.uri = ''
+            self.campaign_list = []
+
         logger.warning(__init_text__)
         logger.warning(f"campaign list: {', '.join(self.campaign_list)}")
 
@@ -48,9 +55,11 @@ class LARDA :
             return self.connect_local(*args, **kwargs)
         elif self.data_source == 'remote':
             return self.connect_remote(*args, **kwargs)
+        elif self.data_source == 'filepath':
+            return self.connect_templates(*args, **kwargs)
 
 
-    def connect_local(self, camp_name, build_lists=True):
+    def connect_local(self, camp_name, build_lists=True, filt=None):
         """built the connector list for the specified campaign (only valid systems are considered)
         the connectors are instances of the Connector.Connector Class
 
@@ -60,6 +69,8 @@ class LARDA :
         Args:
             camp_name (str): name of campaign as defined in ``campaigns.toml``
             build_lists (Bool, optional): Flag to build the filelists or not (with many files this may take some time)
+            filt (list, optional): Filter for name ``['system', 'MIRA']`` or insturment identifiert ``['instr_name', 'hatpro_g2_lacros']``
+    
         """
 
         self.connectors={}
@@ -79,14 +90,20 @@ class LARDA :
         
         paraminformation = ParameterInfo.ParameterInfo(
             self.camp.config_dir, config_file, 
-            cinfo_hand_down=cinfo_hand_down)
+            cinfo_hand_down=cinfo_hand_down, root=ROOT_DIR)
         starttime = time.time()
+        if filt is not None and filt[0] == 'system':
+            assert filt[1] in self.camp.VALID_SYSTEMS, f"{filt[1]} not in VALID_SYSTEMS"
+            self.camp.VALID_SYSTEMS = [filt[1]]
+            filt = None
+
         logger.info("camp.VALID_SYSTEMS {}".format(self.camp.VALID_SYSTEMS))
         
         #if camp_name == 'LACROS_at_Leipzig':
         #    build_lists = False
         # build the filelists or load them from json
-        for system, systeminfo in paraminformation.iterate_systems(keys=self.camp.VALID_SYSTEMS):
+        for system, systeminfo in paraminformation.iterate_systems(
+            keys=self.camp.VALID_SYSTEMS, filter=filt):
             logger.debug('current parameter {} {}'.format(system, systeminfo))
 
             if system in self.camp.system_only:
@@ -110,7 +127,8 @@ class LARDA :
             else:
                 logger.warning("{} not in valid systems".format(system))
 
-        logger.debug('Time for generating connectors {} s'.format(time.time() - starttime))
+        logger.info('Time for generating connectors (build_lists {}) {} s'.format(
+                     build_lists, time.time() - starttime))
         #print "Availability array: ", self.array_avail(2014, 2)
         logger.warning(self.camp.INFO_TEXT)
         logger.info("systems {}".format(self.connectors.keys()))
@@ -119,6 +137,7 @@ class LARDA :
         
 
     def connect_remote(self, camp_name, **kwargs):
+        """"""
         logger.info("connect_remote {}".format(camp_name))
         resp = requests.get(self.uri + '/api/{}/'.format(camp_name))
         #print(resp.json())
@@ -133,6 +152,23 @@ class LARDA :
         logger.warning(self.camp.INFO_TEXT)
         return self
 
+    def connect_templates(self):
+        """"""
+        template_files = list((ROOT_DIR.parent / 'template_params').glob('*'))
+        self.connectors = {}
+
+        for f in template_files:
+            temp = toml.load(f)
+            temp = ParameterInfo.do_parameter_generic_inheritance(temp)
+            for system, systeminfo in temp.items():
+                conn = Connector.Connector(system, systeminfo, [])
+                self.connectors[system] = conn
+
+        logger.info("Systems with default templates {}".format(self.connectors.keys()))
+        logger.info("Parameters in stock: {}".format([(k, self.connectors[k].params_list) for k in self.connectors.keys()]))
+        
+        return self
+
 
     def read(self, system, parameter, time_interval, *further_slices, **kwargs):
         """
@@ -145,7 +181,11 @@ class LARDA :
         Returns:
             the dictionary with data
         """
-        data = self.connectors[system].collect(parameter, time_interval, *further_slices, **kwargs) 
+
+        if self.data_source == 'filepath':
+            data = self.connectors[system].collect_path(parameter, time_interval, *further_slices, **kwargs) 
+        else:
+            data = self.connectors[system].collect(parameter, time_interval, *further_slices, **kwargs) 
 
         return data
 
@@ -246,4 +286,5 @@ class LARDA_campaign_remote:
         self.CONFIGURATION_FILE = self.info_dict["param_config_file"]
         self.LOCATION = self.info_dict["location"]
 
-        self.INFO_TEXT = ''
\ No newline at end of file
+        self.INFO_TEXT = ''
+
